<?php

namespace Btravel\Externaldatum\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Btravel\Externaldatum\Http\Requests\ExternaldataRequest;
use Btravel\Externaldatum\Interfaces\ExternaldataRepositoryInterface;
use Btravel\Externaldatum\Models\Externaldata;

/**
 * Resource controller class for externaldata.
 */
class ExternaldataResourceController extends BaseController
{

    /**
     * Initialize externaldata resource controller.
     *
     * @param type ExternaldataRepositoryInterface $externaldata
     *
     * @return null
     */
    public function __construct(ExternaldataRepositoryInterface $externaldata)
    {
        parent::__construct();
        $this->repository = $externaldata;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Externaldatum\Repositories\Criteria\ExternaldataResourceCriteria::class);
    }

    /**
     * Display a list of externaldata.
     *
     * @return Response
     */
    public function index(ExternaldataRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Btravel\Externaldatum\Repositories\Presenter\ExternaldataPresenter::class)
                ->$function();
        }

        $externaldatas = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('externaldatum::externaldata.names'))
            ->view('externaldatum::externaldata.index', true)
            ->data(compact('externaldatas', 'view'))
            ->output();
    }

    /**
     * Display externaldata.
     *
     * @param Request $request
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function show(ExternaldataRequest $request, Externaldata $externaldata)
    {

        if ($externaldata->exists) {
            $view = 'externaldatum::externaldata.show';
        } else {
            $view = 'externaldatum::externaldata.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('externaldatum::externaldata.name'))
            ->data(compact('externaldata'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new externaldata.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ExternaldataRequest $request)
    {

        $externaldata = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('externaldatum::externaldata.name')) 
            ->view('externaldatum::externaldata.create', true) 
            ->data(compact('externaldata'))
            ->output();
    }

    /**
     * Create new externaldata.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ExternaldataRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $externaldata                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('externaldatum::externaldata.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externaldatum/externaldata/' . $externaldata->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/externaldatum/externaldata'))
                ->redirect();
        }

    }

    /**
     * Show externaldata for editing.
     *
     * @param Request $request
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function edit(ExternaldataRequest $request, Externaldata $externaldata)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('externaldatum::externaldata.name'))
            ->view('externaldatum::externaldata.edit', true)
            ->data(compact('externaldata'))
            ->output();
    }

    /**
     * Update the externaldata.
     *
     * @param Request $request
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function update(ExternaldataRequest $request, Externaldata $externaldata)
    {
        try {
            $attributes = $request->all();

            $externaldata->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('externaldatum::externaldata.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externaldatum/externaldata/' . $externaldata->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externaldatum/externaldata/' . $externaldata->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the externaldata.
     *
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function destroy(ExternaldataRequest $request, Externaldata $externaldata)
    {
        try {

            $externaldata->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externaldatum::externaldata.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('externaldatum/externaldata/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externaldatum/externaldata/' . $externaldata->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple externaldata.
     *
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function delete(ExternaldataRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externaldatum::externaldata.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('externaldatum/externaldata'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externaldatum/externaldata'))
                ->redirect();
        }

    }

    /**
     * Restore deleted externaldatas.
     *
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function restore(ExternaldataRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('externaldatum::externaldata.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/externaldatum/externaldata'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externaldatum/externaldata/'))
                ->redirect();
        }

    }

}
